==> stalker42-0.1.tar.gz: stalker42-0.1/stalker42/main.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
##################################
# AUTHOR:   p-tank <akazian@student.42.fr>
# FILE:     main.py
# CREATED:  19:02:34 09/06/2014
# MODIFIED: 19:02:34 09/06/2014
##################################

import argparse
import sys
from stalker42.stalker import Stalker42
import getpass
import os

def option():
    parser = argparse.ArgumentParser(description="Stalk 42's students")
    information = parser.add_argument_group('information')
    contact_group = parser.add_mutually_exclusive_group()
    parser.add_argument('-v', '--version', action='version', version='%(prog)s: beta 1.0')
    parser.add_argument('contact', nargs='*', default=[],
                         help="list name to stalk")
    information.add_argument('-t', "--tel", action='store_true', default=False, dest="tel",
                             help="mobile-phone, requires connection")
    information.add_argument('-m', '--mail', action='store_true', default=False, dest="mail",
                            help="e-mail, requires connection if not at school")
    information.add_argument('-p', '--place', action='store_true', default=True, dest="place",
                            help="place, requires connection if not at school")
    contact_group.add_argument('-a', '--add', action='store_true', default=False, dest="add",
                            help='add contact to contact [contact] "name" -s "status"')
    contact_group.add_argument('-d', '--del', action='store_true', default=False,  dest="delete",
                            help='del contact to contact list [contact] "name"')
    parser.add_argument('-s', '--status', action='store',  dest="status",
                            help='status')
    parser.add_argument('-u', '--user', action='store',  dest="user",
                            help='user')
    information.add_argument('-c', '--corrector', action='store_true', default=False, dest="corrector",
                            help="find corrector, requires connection")

    return (parser.parse_args())

def print_contact_info(opt, contact):
    for name in contact:
        print("\033[1;33m" + name['name'] + " as " + name['status'] + "\033[0m")
        if opt.place:
            print("place: " + name['place'])
        if opt.mail:
            print("mail: " + name['mail'])
        if opt.tel:
            print("tel: " + name['tel'])
        if opt.corrector:
            print('project: ' + name['project'])

def connect_to_stalk(stalker, user, opt, school):
     pwd = getpass.getpass('password: ')
     try:
        if not school:
            stalker.connectDashboard(user, pwd)
        stalker.connectLdap(user, pwd)
        if opt.corrector:
            stalker.connectIntra(user, pwd)
     except:
        print(sys.argv[0] + ": Connection fail")

def main():
    opt = option()
    contact_info = None
    user = None
    contactfile = os.getcwd() + "/stalker42/contact.csv"
    school = False
    try:
        if os.getenv("MAIL").split('@')[1] == 'student.42.fr':
            school = True
    except:
        school = False
    stalker = Stalker42(contactfile)
    if opt.user:
        user = opt.user
        connect_to_stalk(stalker, user, opt, school)
    elif opt.mail and school:
        stalker.connectLdapSchool()
    if opt.add:
        if opt.status == None:
            status = "student"
        else:
            status = opt.status
        stalker.addContact(opt.contact, status)
        exit(0)
    elif opt.delete:
        stalker.delContact(opt.contact)
        exit(0)
    elif opt.corrector:
        if user == None:
            user = input('Login: ')
            connect_to_stalk(stalker, user, opt, school)
        contact_info = stalker.findCorrector()
    elif len(opt.contact) == 0 and opt.status != None:
        contact_info = stalker.findContact(opt.status)
    elif len(opt.contact) != 0:
        contact_info = stalker.findContact(status="student", contact=opt.contact)
    elif len(opt.contact) == 0 and opt.status == None:
        contact_info = stalker.findContact()
    if contact_info:
        print_contact_info(opt, contact_info)
    else:
        print(os.path.basename(sys.argv[0]) + ": No contact found")

if __name__ == '__main__':
    main()

==> stalker42-0.2.tar.gz: stalker42-0.2/stalker42/main.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
##################################
# AUTHOR:   p-tank <akazian@student.42.fr>
# FILE:     main.py
# CREATED:  19:02:34 09/06/2014
# MODIFIED: 19:02:34 09/06/2014
##################################

import argparse
import sys
from stalker42.stalker import Stalker42
import getpass
import os

def option():
    parser = argparse.ArgumentParser(description="Stalk 42's students")
    information = parser.add_argument_group('information')
    contact_group = parser.add_mutually_exclusive_group()
    parser.add_argument('-v', '--version', action='version', version='%(prog)s: beta 1.0')
    parser.add_argument('contact', nargs='*', default=[],
                         help="list name to stalk")
    information.add_argument('-t', "--tel", action='store_true', default=False, dest="tel",
                             help="mobile-phone, requires connection")
    information.add_argument('-m', '--mail', action='store_true', default=False, dest="mail",
                            help="e-mail, requires connection if not at school")
    information.add_argument('-p', '--place', action='store_true', default=True, dest="place",
                            help="place, requires connection if not at school")
    contact_group.add_argument('-a', '--add', action='store_true', default=False, dest="add",
                            help='add contact to contact [contact] "name" -s "status"')
    contact_group.add_argument('-d', '--del', action='store_true', default=False,  dest="delete",
                            help='del contact to contact list [contact] "name"')
    parser.add_argument('-s', '--status', action='store',  dest="status",
                            help='status')
    parser.add_argument('-u', '--user', action='store',  dest="user",
                            help='user')
    information.add_argument('-c', '--corrector', action='store_true', default=False, dest="corrector",
                            help="find corrector, requires connection")

    return (parser.parse_args())

def print_contact_info(opt, contact):
    for name in contact:
        print("\033[1;33m" + name['name'] + " as " + name['status'] + "\033[0m")
        if opt.place:
            print("place: " + name['place'])
        if opt.mail:
            print("mail: " + name['mail'])
        if opt.tel:
            print("tel: " + name['tel'])
        if opt.corrector:
            print('project: ' + name['project'])

def connect_to_stalk(stalker, user, opt, school):
     pwd = getpass.getpass('password: ')
     try:
        if not school:
            stalker.connectDashboard(user, pwd)
        stalker.connectLdap(user, pwd)
        if opt.corrector:
            stalker.connectIntra(user, pwd)
     except:
        print(sys.argv[0] + ": Connection fail")

def main():
    opt = option()
    contact_info = None
    user = None
    contactfile = os.getenv("HOME") + "/stalker42/contact.csv"
    school = False
    try:
        if os.getenv("MAIL").split('@')[1] == 'student.42.fr':
            school = True
    except:
        school = False
    stalker = Stalker42(contactfile)
    if opt.user:
        user = opt.user
        connect_to_stalk(stalker, user, opt, school)
    elif opt.mail and school:
        stalker.connectLdapSchool()
    if opt.add:
        if opt.status == None:
            status = "student"
        else:
            status = opt.status
        stalker.addContact(opt.contact, status)
        exit(0)
    elif opt.delete:
        stalker.delContact(opt.contact)
        exit(0)
    elif opt.corrector:
        if user == None:
            user = input('Login: ')
            connect_to_stalk(stalker, user, opt, school)
        contact_info = stalker.findCorrector()
    elif len(opt.contact) == 0 and opt.status != None:
        contact_info = stalker.findContact(opt.status)
    elif len(opt.contact) != 0:
        contact_info = stalker.findContact(status="student", contact=opt.contact)
    elif len(opt.contact) == 0 and opt.status == None:
        contact_info = stalker.findContact()
    if contact_info:
        print_contact_info(opt, contact_info)
    else:
        print(os.path.basename(sys.argv[0]) + ": No contact found")

if __name__ == '__main__':
    main()
